@@ -23,9 +23,6 @@ int main (int argc, char *argv[])
     /* initialize user interface */
     at_interface_init();
 
-    /* initialize the track interface */
-    at_track_init();
-    
     gtk_main ();
 
     at_com_cleanup();
