@@ -82,15 +82,30 @@ at_view_delete_callback (GtkWidget *toplevel, GdkEvent *e, gpointer data)
 static void
 at_view_stop_play_record_cmd (GtkWidget *widget, gpointer data)
 {
-  at_com_play_stop (NULL, data);
-  at_com_record_stop (NULL, data);
+    at_com_play_stop (NULL, data);
+    at_com_record_stop (NULL, data);
 }
 
 static void
 at_view_start_play_record_cmd (GtkWidget *widget, gpointer data)
 {
-  at_com_play_start (NULL, data);
-  at_com_record_start (NULL, data);
+    at_com_play_start (NULL, data);
+    at_com_record_start (NULL, data);
+}
+
+static void
+at_view_record_start_cmd (GtkWidget *widget, gpointer data)
+{
+    View *view = data;
+    Track *track;
+    
+    /* TODO: Make a warning box come up - 
+       'You cannot record to the composite track' */
+    track = at_track_get_ID (view->clip->active_track);
+    if (track->is_composite)
+	return;
+
+    at_com_record_start(NULL, data);
 }
 
 void 
@@ -150,7 +165,7 @@ at_view_create_dialog (View *view)
   gtk_toolbar_append_item (GTK_TOOLBAR (toolbar),
 			   "Record", "Start Recording", NULL,
 			   at_interface_pixmap_new (view->toplevel, "record.xpm"),
-			   (GtkSignalFunc) at_com_record_start, (gpointer) view);
+			   (GtkSignalFunc) at_view_record_start_cmd, (gpointer) view);
 
   gtk_toolbar_append_item (GTK_TOOLBAR (toolbar),
 			   "Stop", "Stop Playing and/or Recording", NULL,
